% The MatMol Group (2009)...
% This is a simple example in which only diffusion is considered
% The system is:
%
%   zt = k*zxx ---> discretizacion FEM --> MM*Zt = -(k*DM + BM)*Z + G --->
%   This is the same as Zt = -inv_MM*(k*DM + BM)*Z + inv_MM*G
%
% With boundary conditions
%
%   z(0,t) = 3
%   zx(L,t) = 0
%
% and initial conditions
%
%   z(x,0) = -x^2 + 2*pi*x + 3

clear all

% We start by defining the spatial domain and the discretization
L       = pi;                   % Length of the spatial domain
ndisc   = 21;                   % Number of discretization points
xe      = linspace(0,L,ndisc);  % Spatial discretization

% Call to the function which computes the FEM matrices
[MM, DM, BM] 	= matfem (xe, 'dir', 'neu','MM','DM','BM');
inv_MM          = inv(MM);          % This will be employed later
G               = zeros(ndisc , 1); % For the boundary conditions
G(1)            = BM(1,1)*3;	    % Boundary condition in the first point

% System parameters
k   	= 0.1;

% With the FEM matrices we compute the espatial operator. 
Sp_oper	= - inv_MM*(k*DM + BM);
G	= inv_MM*G;


% Initial conditions
z0	= - xe.^2 + 2*pi*xe + 3;

% Integration time
tf      = 150;
dt      = 1;
tlist	= 0:dt:tf;
steps	= length(tlist)-1;

% Variable initialization (for reservation of memory)
zz      = zeros(ndisc , steps+1);
zz(:,1)	= z0;

% Calling the IVP solver
options	= odeset('AbsTol',1e-6,'RelTol',1e-6);
for ii = 1 : steps
 	[t , z]         = ode15s(@ode_ex1, [tlist(ii) tlist(ii+1)], z0, options, Sp_oper, G);
	z0              = z(end , :)';	% The initial conditions are renewed
	zz(: , ii+1)	= z0;           % The data are saved
end

% Plot the results
figure
mesh(tlist, xe, zz)
xlabel('Time')
ylabel('Length')
zlabel('Field')