% The MatMol Group (2009)...
%... Advection equation (solution with spectral methods)
%...
%...
%... c   = -v*c  + D*c   
%...  t        z      zz
%...
%...
%... where
%...
%...  c       concentration
%...
%...  t       time
%...
%...  z       space
%...
%...  v       fluid velocity
%...
%...  D       diffusion coefficient
%...
%...
%... the boundary conditions (BCs) are taken as
%...
%... c(z=z0,t) = c(t)
%...
%... c(z=zL,t) = 0               
%...  z
%...
%... where
%...
%...  [0,zL]    spatial domain
%...
%... the initial condition (IC) for Burgers' equations are taken as
%...
%... c(z,t=0) = 0
%...
%... the following code computes a solution to the advection equation
%...
%      close all
      clear all
%...
%... start a stopwatch timer
     tic
%...
%... set global variables
     global v D;
     global z0 zL n D1;
%...
%... spatial grid
     z0 = 0.0;
     zL = 1.0;
     n  = 50;
%...
%... model parameters
     v = 0.1;
     D = 0;
%...
%... spectral differentiation
     [D1,z] = chebyshev_spectral_D1(z0,zL,n);
...
%... possibly compared to standard FDs
%     dz = (zL-z0)/(n-1);
%     z = [z0:dz:zL]';
%     [D1] = matfd (z, 'uni', '1st', 5, 'upwind_biased', v);
     % D1 = two_point_upwind_uni_D1(z0,zL,n,v);
%...
%... initial conditions
     c = exp(-((z-0)/0.1).^2);
%...  
%... call to ODE solver 
%...
     t       = [0:1:5];
     options = odeset('RelTol',1e-6,'AbsTol',1e-6);
%...     
     [tout, yout] = ode15s(@advection_pde,t,c,options);
     zint         = linspace(z0,zL,100);
      for i = 1:length(tout),
        yint(i,:) = interp1(z,yout(i,:)',zint,'cubic');
%        yint(i,:)=polyval(polyfit(z,yout(i,:)',n),zint);
        plot(zint,yint(i,:),'r');
        hold on
     end
     plot(z,yout,'*r');
     hold on
     xlabel('z');
     ylabel('c(t,z)');
     hold on
%...
%... read the stopwatch timer
     tcpu=toc;

  
